pysmime.pkcs11

Package pysmime :: Module pkcs11 |
[hide private]
[frames] | no frames]

# Module pkcs11

source code

Interact with OpenSSL by M2Crypto library wrapper and OpenSC pkcs11 engine to access smart cards and retrieve private keys and certificates reference.

Functions | [hide private]
pkcs11_init(pkcs11_engine, pkcs11_driver) Initializes Openssl pkcs11 engine with pkcs11 driver module and returns initialized engine for operations. | source code
pkcs11_login(pkcs11, pin) Performs authentication by PIN on the smart card. | source code
pkcs11_get_data(pkcs11, slot_id) Returns references to private key and certificate stored on the slot_id of the smart card. | source code